@@ -19,6 +19,13 @@ shinyServer(function(input, output) {
                  Group = "group", opacity = input$opacity)
   })
   
+  output$forceRadius <- renderForceNetwork({
+          forceNetwork(Links = MisLinks, Nodes = MisNodes, Source = "source",
+                       Target = "target", Value = "value", NodeID = "name",
+                       Nodesize = 'size', radiusCalculation = " Math.sqrt(d.nodesize)+6",
+                       Group = "group", opacity = input$opacity, legend = T) 
+  })
+  
   output$sankey <- renderSankeyNetwork({
     library(RCurl)
     URL <- "https://raw.githubusercontent.com/christophergandrud/d3Network/sankey/JSONdata/energy.json"
@@ -27,7 +34,7 @@ shinyServer(function(input, output) {
     EngNodes <- JSONtoDF(jsonStr = Energy, array = "nodes")
     sankeyNetwork(Links = EngLinks, Nodes = EngNodes, Source = "source",
                   Target = "target", Value = "value", NodeID = "name",
-                  fontsize = 12, nodeWidth = 30)
+                  fontSize = 12, nodeWidth = 30)
   })
 
   output$rt <- renderTreeNetwork({
